=======
History
=======

0.1.0 (2017-08-27)
------------------

* First release on PyPI.
* Interactive histogram while benchmarking with bokeh.
* Interactive descriptive stats and K-S test.
* Cumulative distribution plots.
* Bucketed resampling.
